# HJRewardsBot

Under construction! Not ready for use yet! Currently experimenting and planning!

Developed by Hassan jlilati (c) 2021

## Examples of How To Use (Buggy Alpha Version)

Creating A Bot
ASk hassan :)
 